@@ -3,9 +3,11 @@ from torch.nn.functional import mse_loss
 from all.logging import DummyWriter
 from all.memory import GeneralizedAdvantageBuffer
 from ._agent import Agent
+from ._parallel_agent import ParallelAgent
+from .a2c import A2CTestAgent
 
 
-class PPO(Agent):
+class PPO(ParallelAgent):
     """
     Proximal Policy Optimization (PPO).
     PPO is an actor-critic style policy gradient algorithm that allows for the reuse of samples
@@ -26,6 +28,7 @@ class PPO(Agent):
         n_steps (int): Number of timesteps per rollout. Updates are performed once per rollout.
         writer (Writer): Used for logging.
     """
+
     def __init__(
             self,
             features,
@@ -138,4 +141,6 @@ class PPO(Agent):
             discount_factor=self.discount_factor,
             lam=self.lam
         )
- 
\ No newline at end of file
+
+
+PPOTestAgent = A2CTestAgent
