@@ -2,8 +2,10 @@ import copy
 import torch
 from .abstract import TargetNetwork
 
+
 class PolyakTarget(TargetNetwork):
     '''TargetNetwork that updates using polyak averaging'''
+
     def __init__(self, rate):
         self._source = None
         self._target = None
@@ -19,7 +21,4 @@ class PolyakTarget(TargetNetwork):
 
     def update(self):
         for target_param, source_param in zip(self._target.parameters(), self._source.parameters()):
-            target_param.data.copy_(
-                target_param.data * (1.0 - self._rate) +
-                source_param.data * self._rate
-            )
+            target_param.data.copy_(target_param.data * (1.0 - self._rate) + source_param.data * self._rate)
