@@ -7,7 +7,6 @@ from all.experiments import SingleEnvExperiment
 from all.logging import Writer
 
 
-# pylint: disable=protected-access
 class MockWriter(Writer):
     def __init__(self, experiment, label, write_loss):
         self.data = {}
@@ -16,7 +15,7 @@ class MockWriter(Writer):
         self.experiment = experiment
 
     def add_scalar(self, key, value, step="frame"):
-        if not key in self.data:
+        if key not in self.data:
             self.data[key] = {"values": [], "steps": []}
         self.data[key]["values"].append(value)
         self.data[key]["steps"].append(self._get_step(step))
@@ -41,10 +40,13 @@ class MockWriter(Writer):
             return self.experiment.episode
         return _type
 
+    def close(self):
+        pass
+
 
 class MockExperiment(SingleEnvExperiment):
-    def _make_writer(self, logdir, agent_name, env_name, write_loss):
-        self._writer = MockWriter(self, agent_name + '_' +  env_name, write_loss)
+    def _make_writer(self, logdir, agent_name, env_name, write_loss, writer):
+        self._writer = MockWriter(self, agent_name + '_' + env_name, write_loss)
         return self._writer
 
 
@@ -56,12 +58,16 @@ class TestSingleEnvExperiment(unittest.TestCase):
         self.env.seed(0)
         self.experiment = None
 
-    def test_adds_label(self):
-        experiment = MockExperiment(dqn(), self.env, quiet=True)
-        self.assertEqual(experiment._writer.label, "_dqn_CartPole-v0")
+    def test_adds_default_name(self):
+        experiment = MockExperiment(self.make_preset(), self.env, quiet=True)
+        self.assertEqual(experiment._writer.label, "dqn_CartPole-v0")
+
+    def test_adds_custom_name(self):
+        experiment = MockExperiment(self.make_preset(), self.env, name='dqn', quiet=True)
+        self.assertEqual(experiment._writer.label, "dqn_CartPole-v0")
 
     def test_writes_training_returns_eps(self):
-        experiment = MockExperiment(dqn(), self.env, quiet=True)
+        experiment = MockExperiment(self.make_preset(), self.env, quiet=True)
         experiment.train(episodes=3)
         np.testing.assert_equal(
             experiment._writer.data["evaluation/returns/episode"]["values"],
@@ -73,7 +79,7 @@ class TestSingleEnvExperiment(unittest.TestCase):
         )
 
     def test_writes_test_returns(self):
-        experiment = MockExperiment(dqn(), self.env, quiet=True)
+        experiment = MockExperiment(self.make_preset(), self.env, quiet=True)
         experiment.train(episodes=5)
         returns = experiment.test(episodes=4)
         expected_mean = 9.5
@@ -93,10 +99,14 @@ class TestSingleEnvExperiment(unittest.TestCase):
         )
 
     def test_writes_loss(self):
-        experiment = MockExperiment(dqn(), self.env, quiet=True, write_loss=True)
+        experiment = MockExperiment(self.make_preset(), self.env, quiet=True, write_loss=True)
         self.assertTrue(experiment._writer.write_loss)
-        experiment = MockExperiment(dqn(), self.env, quiet=True, write_loss=False)
+        experiment = MockExperiment(self.make_preset(), self.env, quiet=True, write_loss=False)
         self.assertFalse(experiment._writer.write_loss)
 
+    def make_preset(self):
+        return dqn.device('cpu').env(self.env).build()
+
+
 if __name__ == "__main__":
     unittest.main()
