@@ -16,10 +16,11 @@ class SoftmaxPolicy(Approximation):
             model parameters, e.g. SGD, Adam, RMSprop, etc.
         kwargs (optional): Any other arguments accepted by all.approximation.Approximation
     '''
+
     def __init__(
             self,
             model,
-            optimizer,
+            optimizer=None,
             name='policy',
             **kwargs
     ):
@@ -34,6 +35,4 @@ class SoftmaxPolicyNetwork(RLNetwork):
     def forward(self, state):
         outputs = super().forward(state)
         probs = functional.softmax(outputs, dim=-1)
-        if self.training:
-            return torch.distributions.Categorical(probs)
-        return torch.argmax(probs, dim=-1)
+        return torch.distributions.Categorical(probs)
